LinkType

Trait LinkType 

pub trait LinkType:
    Number
    + Unsigned
    + Sized
    + TryFrom<u8>
    + FromPrimitive {
    // Required method
    fn funty(n: u8) -> Self;
}
Extension trait providing the funty method for converting small integers to any LinkType.

Required Methods

fn funty(n: u8) -> Self

Convert a small integer (u8) to Self. This is a convenience method for creating zero, one, or small constants.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors